@@ -72,6 +72,7 @@ import net.sourceforge.plantuml.stereo.Stereotag;
 import net.sourceforge.plantuml.stereo.Stereotype;
 import net.sourceforge.plantuml.style.ISkinParam;
 import net.sourceforge.plantuml.style.Style;
+import net.sourceforge.plantuml.style.StyleBuilder;
 import net.sourceforge.plantuml.svek.IEntityImage;
 import net.sourceforge.plantuml.svek.Kal;
 import net.sourceforge.plantuml.svek.Margins;
@@ -86,6 +87,7 @@ import net.sourceforge.plantuml.utils.Position;
 
 final public class Entity implements SpecificBackcolorable, Hideable, Removeable, LineConfigurable, Bag {
 
+	private final StyleBuilder currentStyleBuilder;
 	private final CucaDiagram diagram;
 
 	private final Quark<Entity> quark;
@@ -156,8 +158,10 @@ final public class Entity implements SpecificBackcolorable, Hideable, Removeable
 	}
 
 	// Back to Entity
-	private Entity(LineLocation location, Quark<Entity> quark, CucaDiagram diagram, Bodier bodier, int rawLayout) {
+	private Entity(StyleBuilder currentStyleBuilder, LineLocation location, Quark<Entity> quark, CucaDiagram diagram,
+			Bodier bodier, int rawLayout) {
 		this.location = location;
+		this.currentStyleBuilder = currentStyleBuilder;
 		this.quark = Objects.requireNonNull(quark);
 		this.diagram = diagram;
 		if (quark.isRoot())
@@ -169,15 +173,15 @@ final public class Entity implements SpecificBackcolorable, Hideable, Removeable
 		this.quark.setData(this);
 	}
 
-	public Entity(LineLocation location, Quark<Entity> quark, CucaDiagram diagram, Bodier bodier, LeafType leafType,
-			int rawLayout) {
-		this(location, Objects.requireNonNull(quark), diagram, bodier, rawLayout);
+	public Entity(StyleBuilder currentStyleBuilder, LineLocation location, Quark<Entity> quark, CucaDiagram diagram,
+			Bodier bodier, LeafType leafType, int rawLayout) {
+		this(currentStyleBuilder, location, Objects.requireNonNull(quark), diagram, bodier, rawLayout);
 		this.leafType = leafType;
 	}
 
-	public Entity(LineLocation location, Quark<Entity> quark, CucaDiagram diagram, Bodier bodier, GroupType groupType,
-			int rawLayout) {
-		this(location, Objects.requireNonNull(quark), diagram, bodier, rawLayout);
+	public Entity(StyleBuilder currentStyleBuilder, LineLocation location, Quark<Entity> quark, CucaDiagram diagram,
+			Bodier bodier, GroupType groupType, int rawLayout) {
+		this(currentStyleBuilder, location, Objects.requireNonNull(quark), diagram, bodier, rawLayout);
 		this.groupType = groupType;
 	}
 
@@ -742,4 +746,17 @@ final public class Entity implements SpecificBackcolorable, Hideable, Removeable
 		return location;
 	}
 
+	public StyleBuilder getCurrentStyleBuilder() {
+
+		// See https://github.com/plantuml/plantuml/issues/2171 for background.
+		// If skinParam directive has been used in the diagram, retrieve the latest style builder
+		// from SkinParam for backward compatibility with previous behavior.
+		if (diagram.isSkinParamUsed())
+			return getSkinParam().getCurrentStyleBuilder();
+
+		// If skinParam directive is not used, support local styles by returning the style builder
+		// that was active when the entity was created (currentStyleBuilder).
+		return currentStyleBuilder;
+	}
+
 }
