@@ -437,9 +437,12 @@ public class SvgGraphics {
 		return color == null || "#00000000".equals(color) ? "none" : color;
 	}
 
-	public final void setStrokeWidth(double strokeWidth, String strokeDasharray) {
+	public final void setStrokeWidth(double strokeWidth, double[] strokeDasharray) {
 		this.strokeWidth = format(strokeWidth);
-		this.strokeDasharray = strokeDasharray;
+		if (strokeDasharray == null)
+			this.strokeDasharray = null;
+		else
+			this.strokeDasharray = "" + format(strokeDasharray[0]) + "," + format(strokeDasharray[1]);
 	}
 
 	public final Element getG() {
@@ -648,7 +651,7 @@ public class SvgGraphics {
 
 	private Transformer getTransformer() throws TransformerException {
 		final Transformer transformer = XmlFactories.newTransformer();
-		Log.info("Transformer=" + transformer.getClass());
+		Log.info(() -> "Transformer=" + transformer.getClass());
 
 		// // Sets the standalone property in the first line of
 		// // the output file.
@@ -716,7 +719,7 @@ public class SvgGraphics {
 	public void svgPath(double x, double y, UPath path, double deltaShadow) {
 		manageShadow(deltaShadow);
 		ensureVisible(x, y);
-		final StringBuilder sb = new StringBuilder();
+		final StringBuilder sb = new StringBuilder(path.size() * 12);
 		for (USegment seg : path) {
 			final USegmentType type = seg.getSegmentType();
 			final double coord[] = seg.getCoord();
@@ -823,14 +826,22 @@ public class SvgGraphics {
 
 	private String format(double xx) {
 		final double x = xx * option.getScale();
-		if (x == 0)
+		if (x == 0.0)
 			return "0";
 
-		String s = String.format(Locale.US, "%1.4f", x);
-		s = s.replaceAll("(\\.\\d*?)0+$", "$1");
-		if (s.endsWith("."))
-			s = s.substring(0, s.length() - 1);
+		String s = String.format(Locale.US, "%.4f", x);
 
+		final int dot = s.indexOf('.');
+		if (dot >= 0) {
+			int end = s.length() - 1;
+			while (end > dot && s.charAt(end) == '0')
+				end--;
+
+			if (end == dot)
+				end--;
+
+			s = s.substring(0, end + 1);
+		}
 		return s;
 	}
 
@@ -898,7 +909,7 @@ public class SvgGraphics {
 			final String pos = "<svg x=\"" + format(x) + "\" y=\"" + format(y) + "\">";
 			svg = pos + svg.substring(5);
 			final String key = "imagesvginlined" + image.getMD5Hex() + images.size();
-			final Element elt =  document.createElement(key);
+			final Element elt = document.createElement(key);
 			getG().appendChild(elt);
 			images.put(key, svg);
 		}
@@ -1055,11 +1066,12 @@ public class SvgGraphics {
 			this.target = target;
 		}
 
+		private static final Pattern p = Pattern.compile("\\<U\\+([0-9A-Fa-f]+)\\>");
+
 		String getXlinkTitle() {
 			if (title == null)
 				return url;
 
-			final Pattern p = Pattern.compile("\\<U\\+([0-9A-Fa-f]+)\\>");
 			final Matcher m = p.matcher(title);
 			final StringBuffer sb = new StringBuffer(); // Can't be switched to StringBuilder in order to support Java 8
 			while (m.find()) {
