@@ -113,6 +113,8 @@ public class FromSkinparamToStyle {
 		addConvert("SequenceBoxFontColor", PName.FontColor, SName.box);
 		addConvert("SequenceLifeLineBorderColor", PName.LineColor, SName.lifeLine);
 		addConvert("SequenceLifeLineBackgroundColor", PName.BackGroundColor, SName.lifeLine);
+		addConFont("sequenceDelay", SName.delay);
+		addConvert("sequenceDelayBorderColor", PName.LineColor, SName.delay);
 		addConvert("sequenceDividerBackgroundColor", PName.BackGroundColor, SName.separator);
 		addConvert("sequenceDividerBorderColor", PName.LineColor, SName.separator);
 		addConFont("sequenceDivider", SName.separator);
@@ -396,7 +398,7 @@ public class FromSkinparamToStyle {
 		if (stereo != null) {
 			map = StyleLoader.addPriorityForStereotype(map);
 			for (String s : stereo.split("\\&"))
-				sig = sig.add(StereotypeDecoration.PREFIX + s);
+				sig = sig.addStereotype(s);
 		}
 
 		final Style style = new Style(sig, map);
